jk_json
=======

Introduction
------------

This python module provides parser and validator for JSON files and data structures.

The JSON parser is designed as a drop-in replacement for the built in python JSON parser as this parser here supports using comments in JSON files (which in some use cases is very a very handy feature).

Information about this module can be found here:

* [github.org](https://github.com/jkpubsrc/python-module-jk-json)
* [pypi.python.org](https://pypi.python.org/pypi/jk_json)

Why a replacement?
------------------

For two reasons:

1. The existing JSON library does report errors in the data format very well.
2. The existing JSON library can't cope with comments. Unfortunately comments in JSON files are a very nice thing.

How to use this module
----------------------

(TODO)

Author(s)
-------------------

* Jürgen Knauth: pubsrc@binary-overflow.de

License
-------

This software is provided under the following license:

* Apache Software License 2.0



